@@ -1,7 +1,5 @@
 from os.path import basename, dirname, exists, isdir, isfile, join, realpath, split
 import glob
-from shutil import rmtree
-from six import with_metaclass
 
 import hashlib
 from re import match
@@ -11,16 +9,21 @@ import shutil
 import fnmatch
 import urllib.request
 from urllib.request import urlretrieve
-from os import listdir, unlink, environ, mkdir, curdir, walk
+from os import listdir, unlink, environ, curdir, walk
 from sys import stdout
 import time
 try:
     from urlparse import urlparse
 except ImportError:
     from urllib.parse import urlparse
-from pythonforandroid.logger import (logger, info, warning, debug, shprint, info_main)
-from pythonforandroid.util import (current_directory, ensure_dir,
-                                   BuildInterruptingException)
+
+import packaging.version
+
+from pythonforandroid.logger import (
+    logger, info, warning, debug, shprint, info_main)
+from pythonforandroid.util import (
+    current_directory, ensure_dir, BuildInterruptingException, rmdir, move,
+    touch)
 from pythonforandroid.util import load_source as import_recipe
 
 
@@ -40,7 +43,7 @@ class RecipeMeta(type):
         return super().__new__(cls, name, bases, dct)
 
 
-class Recipe(with_metaclass(RecipeMeta)):
+class Recipe(metaclass=RecipeMeta):
     _url = None
     '''The address from which the recipe may be downloaded. This is not
     essential, it may be omitted if the source is available some other
@@ -123,8 +126,8 @@ class Recipe(with_metaclass(RecipeMeta)):
     """
 
     need_stl_shared = False
-    '''Some libraries or python packages may need to be linked with android's
-    stl. We can automatically do this for any recipe if we set this property to
+    '''Some libraries or python packages may need the c++_shared in APK.
+    We can automatically do this for any recipe if we set this property to
     `True`'''
 
     stl_lib_name = 'c++_shared'
@@ -214,24 +217,26 @@ class Recipe(with_metaclass(RecipeMeta)):
                 break
             return target
         elif parsed_url.scheme in ('git', 'git+file', 'git+ssh', 'git+http', 'git+https'):
-            if isdir(target):
-                with current_directory(target):
-                    shprint(sh.git, 'fetch', '--tags', '--recurse-submodules')
-                    if self.version:
-                        shprint(sh.git, 'checkout', self.version)
-                    branch = sh.git('branch', '--show-current')
-                    if branch:
-                        shprint(sh.git, 'pull')
-                        shprint(sh.git, 'pull', '--recurse-submodules')
-                    shprint(sh.git, 'submodule', 'update', '--recursive')
-            else:
+            if not isdir(target):
                 if url.startswith('git+'):
                     url = url[4:]
-                shprint(sh.git, 'clone', '--recursive', url, target)
+                # if 'version' is specified, do a shallow clone
                 if self.version:
+                    ensure_dir(target)
                     with current_directory(target):
-                        shprint(sh.git, 'checkout', self.version)
-                        shprint(sh.git, 'submodule', 'update', '--recursive')
+                        shprint(sh.git, 'init')
+                        shprint(sh.git, 'remote', 'add', 'origin', url)
+                else:
+                    shprint(sh.git, 'clone', '--recursive', url, target)
+            with current_directory(target):
+                if self.version:
+                    shprint(sh.git, 'fetch', '--depth', '1', 'origin', self.version)
+                    shprint(sh.git, 'checkout', self.version)
+                branch = sh.git('branch', '--show-current')
+                if branch:
+                    shprint(sh.git, 'pull')
+                    shprint(sh.git, 'pull', '--recurse-submodules')
+                shprint(sh.git, 'submodule', 'update', '--recursive', '--init', '--depth', '1')
             return target
 
     def apply_patch(self, filename, arch, build_dir=None):
@@ -366,7 +371,7 @@ class Recipe(with_metaclass(RecipeMeta)):
             if expected_digest:
                 expected_digests[alg] = expected_digest
 
-        shprint(sh.mkdir, '-p', join(self.ctx.packages_path, self.name))
+        ensure_dir(join(self.ctx.packages_path, self.name))
 
         with current_directory(join(self.ctx.packages_path, self.name)):
             filename = shprint(sh.basename, url).stdout[:-1].decode('utf-8')
@@ -395,7 +400,7 @@ class Recipe(with_metaclass(RecipeMeta)):
 
                 shprint(sh.rm, '-f', marker_filename)
                 self.download_file(self.versioned_url, filename)
-                shprint(sh.touch, marker_filename)
+                touch(marker_filename)
 
                 if exists(filename) and isfile(filename):
                     for alg, expected_digest in expected_digests.items():
@@ -422,9 +427,7 @@ class Recipe(with_metaclass(RecipeMeta)):
                 self.name.lower()))
             if exists(self.get_build_dir(arch)):
                 return
-            shprint(sh.rm, '-rf', build_dir)
-            shprint(sh.mkdir, '-p', build_dir)
-            shprint(sh.rmdir, build_dir)
+            rmdir(build_dir)
             ensure_dir(build_dir)
             shprint(sh.cp, '-a', user_dir, self.get_build_dir(arch))
             return
@@ -446,7 +449,7 @@ class Recipe(with_metaclass(RecipeMeta)):
                 extraction_filename = join(
                     self.ctx.packages_path, self.name, filename)
                 if isfile(extraction_filename):
-                    if extraction_filename.endswith('.zip'):
+                    if extraction_filename.endswith(('.zip', '.whl')):
                         try:
                             sh.unzip(extraction_filename)
                         except (sh.ErrorReturnCode_1, sh.ErrorReturnCode_2):
@@ -459,20 +462,20 @@ class Recipe(with_metaclass(RecipeMeta)):
                         fileh = zipfile.ZipFile(extraction_filename, 'r')
                         root_directory = fileh.filelist[0].filename.split('/')[0]
                         if root_directory != basename(directory_name):
-                            shprint(sh.mv, root_directory, directory_name)
+                            move(root_directory, directory_name)
                     elif extraction_filename.endswith(
                             ('.tar.gz', '.tgz', '.tar.bz2', '.tbz2', '.tar.xz', '.txz')):
                         sh.tar('xf', extraction_filename)
                         root_directory = sh.tar('tf', extraction_filename).stdout.decode(
                                 'utf-8').split('\n')[0].split('/')[0]
                         if root_directory != basename(directory_name):
-                            shprint(sh.mv, root_directory, directory_name)
+                            move(root_directory, directory_name)
                     else:
                         raise Exception(
                             'Could not extract {} download, it must be .zip, '
                             '.tar.gz or .tar.bz2 or .tar.xz'.format(extraction_filename))
                 elif isdir(extraction_filename):
-                    mkdir(directory_name)
+                    ensure_dir(directory_name)
                     for entry in listdir(extraction_filename):
                         if entry not in ('.git',):
                             shprint(sh.cp, '-Rv',
@@ -492,20 +495,6 @@ class Recipe(with_metaclass(RecipeMeta)):
         if arch is None:
             arch = self.filtered_archs[0]
         env = arch.get_env(with_flags_in_cc=with_flags_in_cc)
-
-        if self.need_stl_shared:
-            env['CPPFLAGS'] = env.get('CPPFLAGS', '')
-            env['CPPFLAGS'] += ' -I{}'.format(self.ctx.ndk.libcxx_include_dir)
-
-            env['CXXFLAGS'] = env['CFLAGS'] + ' -frtti -fexceptions'
-
-            if with_flags_in_cc:
-                env['CXX'] += ' -frtti -fexceptions'
-
-            env['LDFLAGS'] += ' -L{}'.format(arch.ndk_lib_dir)
-            env['LIBS'] = env.get('LIBS', '') + " -l{}".format(
-                self.stl_lib_name
-            )
         return env
 
     def prebuild_arch(self, arch):
@@ -546,7 +535,7 @@ class Recipe(with_metaclass(RecipeMeta)):
                         patch.format(version=self.version, arch=arch.arch),
                         arch.arch, build_dir=build_dir)
 
-            shprint(sh.touch, join(build_dir, '.patched'))
+            touch(join(build_dir, '.patched'))
 
     def should_build(self, arch):
         '''Should perform any necessary test and return True only if it needs
@@ -627,13 +616,11 @@ class Recipe(with_metaclass(RecipeMeta)):
                     'build dirs'.format(self.name))
 
         for directory in dirs:
-            if exists(directory):
-                info('Deleting {}'.format(directory))
-                shutil.rmtree(directory)
+            rmdir(directory)
 
         # Delete any Python distributions to ensure the recipe build
         # doesn't persist in site-packages
-        shutil.rmtree(self.ctx.python_installs_dir)
+        rmdir(self.ctx.python_installs_dir)
 
     def install_libs(self, arch, *libs):
         libs_dir = self.ctx.get_libs_dir(arch.arch)
@@ -644,7 +631,7 @@ class Recipe(with_metaclass(RecipeMeta)):
         shprint(sh.cp, *args)
 
     def has_libs(self, arch, *libs):
-        return all(map(lambda l: self.ctx.has_lib(arch.arch, l), libs))
+        return all(map(lambda lib: self.ctx.has_lib(arch.arch, lib), libs))
 
     def get_libraries(self, arch_name, in_context=False):
         """Return the full path of the library depending on the architecture.
@@ -734,7 +721,7 @@ class IncludedFilesBehaviour(object):
         if self.src_filename is None:
             raise BuildInterruptingException(
                 'IncludedFilesBehaviour failed: no src_filename specified')
-        shprint(sh.rm, '-rf', self.get_build_dir(arch))
+        rmdir(self.get_build_dir(arch))
         shprint(sh.cp, '-a', join(self.get_recipe_dir(), self.src_filename),
                 self.get_build_dir(arch))
 
@@ -874,7 +861,7 @@ class PythonRecipe(Recipe):
                 build_dir = join(site_packages_dir[0], name)
                 if exists(build_dir):
                     info('Deleted {}'.format(build_dir))
-                    rmtree(build_dir)
+                    rmdir(build_dir)
 
     @property
     def real_hostpython_location(self):
@@ -1161,8 +1148,8 @@ class TargetPythonRecipe(Recipe):
 
     @property
     def major_minor_version_string(self):
-        from distutils.version import LooseVersion
-        return '.'.join([str(v) for v in LooseVersion(self.version).version[:2]])
+        parsed_version = packaging.version.parse(self.version)
+        return f"{parsed_version.major}.{parsed_version.minor}"
 
     def create_python_bundle(self, dirn, arch):
         """
@@ -1184,7 +1171,10 @@ class TargetPythonRecipe(Recipe):
             parts = file_basename.split('.')
             if len(parts) <= 2:
                 continue
-            shprint(sh.mv, filen, join(file_dirname, parts[0] + '.so'))
+            # PySide6 libraries end with .abi3.so
+            if parts[1] == "abi3":
+                continue
+            move(filen, join(file_dirname, parts[0] + '.so'))
 
 
 def algsum(alg, filen):
