@@ -3,8 +3,8 @@ from pythonforandroid.recipe import CythonRecipe
 
 class ScryptRecipe(CythonRecipe):
 
-    version = '0.8.6'
-    url = 'https://bitbucket.org/mhallin/py-scrypt/get/v{version}.zip'
+    version = '0.8.20'
+    url = 'https://github.com/holgern/py-scrypt/archive/refs/tags/v{version}.zip'
     depends = ['setuptools', 'openssl']
     call_hostpython_via_targetpython = False
     patches = ["remove_librt.patch"]
@@ -13,7 +13,7 @@ class ScryptRecipe(CythonRecipe):
         """
         Adds openssl recipe to include and library path.
         """
-        env = super(ScryptRecipe, self).get_recipe_env(arch, with_flags_in_cc)
+        env = super().get_recipe_env(arch, with_flags_in_cc)
         openssl_recipe = self.get_recipe('openssl', self.ctx)
         env['CFLAGS'] += openssl_recipe.include_flags(arch)
         env['LDFLAGS'] += ' -L{}'.format(self.ctx.get_libs_dir(arch.arch))
